Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3282)

Unified Diff: chrome/browser/ui/cocoa/extensions/chooser_dialog_cocoa_controller.h

Issue 2065803002: Make ChromeExtensionChooserDialog::ShowDialog work for MacViews (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: removed TODO comments Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/extensions/chooser_dialog_cocoa_controller.h
diff --git a/chrome/browser/ui/cocoa/extensions/chooser_dialog_cocoa_controller.h b/chrome/browser/ui/cocoa/extensions/chooser_dialog_cocoa_controller.h
index c5c43273a20aed027a66b94b49e5c819bcc9806f..1581f53a644ff7e76bb6a98ca452cce194f729fe 100644
--- a/chrome/browser/ui/cocoa/extensions/chooser_dialog_cocoa_controller.h
+++ b/chrome/browser/ui/cocoa/extensions/chooser_dialog_cocoa_controller.h
@@ -9,7 +9,7 @@
#include "base/mac/scoped_nsobject.h"
-@class ChooserContentView;
+@class ChooserContentViewCocoa;
class ChooserController;
class ChooserDialogCocoa;
@@ -17,7 +17,7 @@ class ChooserDialogCocoa;
// of the selected option.
@interface ChooserDialogCocoaController
: NSViewController<NSTableViewDataSource, NSTableViewDelegate> {
- base::scoped_nsobject<ChooserContentView> chooserContentView_;
+ base::scoped_nsobject<ChooserContentViewCocoa> chooserContentViewCocoa_;
tapted 2016/06/14 08:49:03 I see you need to rename the class to avoid a symb
juncai 2016/06/14 18:08:23 Done.
NSTableView* tableView_; // Weak.
NSButton* connectButton_; // Weak.
NSButton* cancelButton_; // Weak.
@@ -54,8 +54,8 @@ initWithChooserDialogCocoa:(ChooserDialogCocoa*)chooserDialogCocoa
// Called when the "Get help" button is pressed.
- (void)onHelpPressed:(id)sender;
-// Gets the |chooserContentView_|. For testing only.
-- (ChooserContentView*)chooserContentView;
+// Gets the |chooserContentViewCocoa_|. For testing only.
+- (ChooserContentViewCocoa*)chooserContentViewCocoa;
@end

Powered by Google App Engine
This is Rietveld 408576698